#!/bin/sh
# This file contains some 'visual tests' for ctioga to make sure that when
# I add some features to ctioga, I don't break everything existing.
# As such, it also stands as a 'feature list' for ctioga.

. ./test_style.sh

ctioga -t 'Basic curve' 'sin(x)'

ctioga -N -t 'Several styles' 'sin(x)' 'cos(x)' 'tan(x)'

